==> qmmp-1.6.8.tar.bz2: qmmp-1.6.8/src/plugins/General/streambrowser/translations/streambrowser_plugin_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>EditStreamDialog</name>
    <message>
        <location filename="../editstreamdialog.ui" line="14"/>
        <source>Edit Stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="34"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="44"/>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="54"/>
        <source>Genre:</source>
        <translation>Genre:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="64"/>
        <source>Bitrate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="74"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
</context>
<context>
    <name>StreamBrowser</name>
    <message>
        <location filename="../streambrowser.cpp" line="33"/>
        <source>Add Stream</source>
        <translation>Lägg till ström</translation>
    </message>
    <message>
        <location filename="../streambrowser.cpp" line="34"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
</context>
<context>
    <name>StreamBrowserFactory</name>
    <message>
        <location filename="../streambrowserfactory.cpp" line="29"/>
        <source>Stream Browser Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="50"/>
        <source>About Stream Browser Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="51"/>
        <source>Qmmp Stream Browser Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="52"/>
        <source>This plugin allows one to add stream from IceCast stream directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Skriven av: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>StreamWindow</name>
    <message>
        <location filename="../streamwindow.ui" line="14"/>
        <source>Stream Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="31"/>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="47"/>
        <source>Favorites</source>
        <translation>Favoriter</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="73"/>
        <source>IceCast</source>
        <translation>IceCast</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="102"/>
        <source>Add</source>
        <translation>Lägg till</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="109"/>
        <source>Update</source>
        <translation>Uppdatera</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="55"/>
        <location filename="../streamwindow.cpp" line="73"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="56"/>
        <location filename="../streamwindow.cpp" line="74"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="57"/>
        <location filename="../streamwindow.cpp" line="75"/>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="58"/>
        <location filename="../streamwindow.cpp" line="76"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="133"/>
        <source>&amp;Add to favorites</source>
        <translation>&amp;Lägg till i favoriter</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="136"/>
        <source>&amp;Add to playlist</source>
        <translation>&amp;Lägg till i spellista</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="139"/>
        <source>&amp;Create</source>
        <translation>&amp;Skapa</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="141"/>
        <source>&amp;Edit</source>
        <translation>&amp;Redigera</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="144"/>
        <source>&amp;Remove</source>
        <translation>&amp;Ta bort</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="156"/>
        <source>Done</source>
        <translation>Klart</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="159"/>
        <location filename="../streamwindow.cpp" line="160"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="179"/>
        <source>Receiving</source>
        <translation>Hämtar</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="282"/>
        <source>Edit Stream</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-1.7.4.tar.bz2: qmmp-1.7.4/src/plugins/General/streambrowser/translations/streambrowser_plugin_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv_SE">
<context>
    <name>EditStreamDialog</name>
    <message>
        <location filename="../editstreamdialog.ui" line="14"/>
        <source>Edit Stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="34"/>
        <source>URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="44"/>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="54"/>
        <source>Genre:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="64"/>
        <source>Bitrate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="74"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamBrowser</name>
    <message>
        <location filename="../streambrowser.cpp" line="33"/>
        <source>Add Stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streambrowser.cpp" line="34"/>
        <source>Ctrl+U</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamBrowserFactory</name>
    <message>
        <location filename="../streambrowserfactory.cpp" line="29"/>
        <source>Stream Browser Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="50"/>
        <source>About Stream Browser Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="51"/>
        <source>Qmmp Stream Browser Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="52"/>
        <source>This plugin allows one to add stream from IceCast stream directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamWindow</name>
    <message>
        <location filename="../streamwindow.ui" line="14"/>
        <source>Stream Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="31"/>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="47"/>
        <source>Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="73"/>
        <source>IceCast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="102"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="109"/>
        <source>Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="55"/>
        <location filename="../streamwindow.cpp" line="69"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="55"/>
        <location filename="../streamwindow.cpp" line="69"/>
        <source>Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="55"/>
        <location filename="../streamwindow.cpp" line="69"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="55"/>
        <location filename="../streamwindow.cpp" line="69"/>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="125"/>
        <source>&amp;Add to favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="128"/>
        <source>&amp;Add to playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="131"/>
        <source>&amp;Create</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="132"/>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="135"/>
        <source>&amp;Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="147"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="150"/>
        <location filename="../streamwindow.cpp" line="151"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="170"/>
        <source>Receiving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="273"/>
        <source>Edit Stream</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
